#!/bin/bash
#This shell script will help you to install the alsa driver
PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:~/bin
export PATH

KERNEL_VER=`uname -r`
DRIVER_VER=1.0.14
LIB_VER=1.0.14a
UTILS_VER=1.0.14

function rmfolder() {
rm -rf alsa-driver-$DRIVER_VER > /dev/null
rm -rf alsa-lib-$LIB_VER > /dev/null
rm -rf alsa-utils-$UTILS_VER > /dev/null
}

echo "I'll help you to install the alsa driver now."
echo 
sleep 1

#Check if user are using root account
echo "First, check if you are using root account."
if [ $UID -ne 0 ]
then echo "Please login as root." && exit 0
else echo "OK,go on."
fi
sleep 2

#Check if user have installed the kernel source
echo "Second, please make sure you have installed the kernel source."
if [ ! -d /lib/modules/$KERNEL_VER/build/ ]
  then echo "You haven't installed the kernel source,interrupt." && exit 0
else echo "It's OK."
fi
sleep 2

#Check if user have installed gcc and automake
echo "Third, please make sure you have installed gcc and automake."
gcc --version >/dev/null 2>&1
if [ $? -ne 0 ]
then echo "You haven't installed gcc,interrupt." && exit 0
fi
automake --version >/dev/null 2>&1
if [ $? -ne 0 ] 
then echo "You haven't installed automake,interrupt." && exit 0
fi

#Decompress the driver source
echo "Then, I'll installed the driver for you."
echo "Deompress the driver source"
tar jxvf alsa-driver-$DRIVER_VER.tar.tar > /dev/null
tar jxvf alsa-lib-$LIB_VER.tar.tar > /dev/null
tar jxvf alsa-utils-$UTILS_VER.tar.tar > /dev/null
sync
sleep 2

echo "Remove old sound driver"
if [ -d /lib/modules/$KERNEL_VER/kernel/sound ]; then
   rm -rf /lib/modules/$KERNEL_VER/kernel/sound/pci > /dev/null 2>&1
   rm -rf /lib/modules/$KERNEL_VER/kernel/sound/acore > /dev/null 2>&1
   rm -rf /lib/modules/$KERNEL_VER/kernel/sound/driver > /dev/null 2>&1
fi

## remove driver modules
if [ -f /etc/rc.d/init.d/alsasound ]; then
   /etc/init.d/alsasound stop 2> /dev/null
   rmmod snd-page-alloc > /dev/null 2>&1 
   rmmod soundcore > /dev/null 2>&1
fi

sleep 2

echo "Compile Driver........"
cd alsa-driver-$DRIVER_VER
./configure --with-cards=hda-intel
if [ $? -ne 0 ]
then echo "configure failed, please check about your settings!" ;
rmfolder ;
exit 1 ;
fi
make
make install
if [ $? -ne 0 ]
then echo "Alsa driver compiling failed!" ;
rmfolder ;
exit 1 ;
fi
./snddevices
cd ..

## for x86
echo "Remove old alsa library"
rm -rf /lib/libasound.* > /dev/null 2>&1 
rm -rf /lib64/libasound.* > /dev/null 2>&1 
rm -rf /usr/lib/libasound.* > /dev/null 2>&1 
rm -rf /usr/lib64/libasound.* > /dev/null 2>&1

echo "Compile ALSA Library....."
cd alsa-lib-$LIB_VER
./configure
make
make install
if [ $? -ne 0 ]
then echo "Alsa Libarary compiling failed!" ;
rmfolder ;
exit 1
fi
cd ..


echo "Compile ALSA Utility......"
cd alsa-utils-$UTILS_VER
./configure
make
make install
if [ $? -ne 0 ]
  then echo "Alsa utility compiling failed!" 
rmfolder
exit 1
fi
cd ..

## for x86_64
if [ -d /usr/lib64 ]; then
  cp -lf /usr/lib/libasound.* /usr/lib64
  cp -lf /usr/lib/pkgconfig/alsa.pc /usr/lib64/pkgconfig
  ldconfig -n /usr/lib64
fi

sleep 1

## del audio stat file
if [ -f /etc/asound.state ]; then
   rm -rf /etc/asound.state > /dev/null 2>&1
fi

## alsa driver sndstat file relink
rm -rf /dev/sndstat > /dev/null 2>&1
ln -s /proc/asound/oss/sndstat /dev/sndstat


echo "Remove Folder....."
rmfolder

echo "Configure the alsa driver....."
alsaconf

echo "May I restart your computer to load new driver?"
read -p "Press Y/y to restart your computer." var
case $var in 
"Y") shutdown -r now
 ;;
"y") shutdown -r now
 ;;
*) echo "OK,I'll exit the script now." && exit 0
 ;;
esac
